`model.matrix.eRm` <-
function(object,...) object$W                 #design matrix

